#!/bin/sh

GLEST_LOCAL_DIR=$HOME/.glest
GLEST_DATA_DIR=/usr/share/games/glest
GLEST_EXECUTABLE=/usr/games/glest.bin

glxinfo | grep -e "OpenGL vendor string: NVIDIA" \
               -e "OpenGL vendor string: ATI" &> /dev/null
if [ $? -ne 0 -a ! -f $GLEST_LOCAL_DIR/ignore_warning ]; then
  xmessage -buttons Exit:0,Continue:1,Ignore\ forever:2 \
           -default Exit \
           -center \
           -file $GLEST_DATA_DIR/info \
           -print
  result=$?

  case $result in
    0)
      exit 1;
      ;;
    1)
      ;;
    2) 
      test -d $GLEST_LOCAL_DIR || mkdir $GLEST_LOCAL_DIR
      touch $GLEST_LOCAL_DIR/ignore_warning
      ;;
    *)
      ;;
  esac
fi

tmplang="$LANG"
test "$LC_MESSAGES" != "" && tmplang="$LC_MESSAGES"
test "$LC_ALL"      != "" && tmplang="$LC_ALL"
test "$LANGUAGE"    != "" && tmplang="$LANGUAGE"

lang=`echo $tmplang|cut -d "_" -f 1`

case $lang in
  ct)
    lang=catala.lng
  ;;
  cz)
    lang=cesky.lng
  ;;
  da)
    lang=dansk.lng
  ;;
  de)
    lang=german.lng
  ;;
  eu)
    lang=euskara.lng
  ;;
  es)
    lang=lang=$(echo espaol | iconv -f UTF-8 -t ISO-8859-1)
  ;;
  fr)
    lang=francais.lng
  ;;
  gl)
    lang=galego.lng
  ;;
  gr)
    lang=greek.lng
  ;;
  he)
    lang=hebrew.lng
  ;;
  hu)
    lang=magyar.lng
  ;;
  it)
    lang=italian.lng
  ;;
  nb|nn)
    lang=norsk.lng
  ;;
  nl)
    lang=dutch.lng
  ;;
  pl)
    lang=polish.lng
  ;;
  pt)
    lang=portugues.lng
  ;;
  ru)
    lang=russian.lng
  ;;
  sl)
    lang=slovak.lng
  ;;
  sr)
    lang=srpski.lng
  ;;
  tr)
    lang=turkish.lng
  ;;
  *)
    lang=english.lng
  ;;
esac

mkdir -p $GLEST_LOCAL_DIR
cd $GLEST_LOCAL_DIR
ln -snf $GLEST_DATA_DIR/techs
ln -snf $GLEST_DATA_DIR/data
ln -snf $GLEST_DATA_DIR/maps
ln -snf $GLEST_DATA_DIR/scenarios
ln -snf $GLEST_DATA_DIR/screens
ln -snf $GLEST_DATA_DIR/shaders
ln -snf $GLEST_DATA_DIR/tilesets
if [ ! -e glest.ini ]; then
  X=$(xdpyinfo|grep "dimensions:"|awk '{print $2}'|cut -d "x" -f 1)
  Y=$(xdpyinfo|grep "dimensions:"|awk '{print $2}'|cut -d "x" -f 2)
  sed -e s/ScreenWidth=.*/ScreenWidth=$X/g \
      -e s/ScreenHeight=.*/ScreenHeight=$Y/g \
      -e s/Lang=.*/Lang=$lang/g \
      $GLEST_DATA_DIR/glest.ini > glest.ini
else
  # convert configuration from glest 1.1 to glest 1.2
  grep -q -e ChangeDisplay -e PathFindLevelsMax glest.ini
  if [ $? -eq 0 ]; then
    sed -e s/ChangeDisplay=1/Windowed=0/g \
        -e s/ChangeDisplay=0/Windowed=1/g \
        -e s/PathFindLevelsMax/PathFindNodesMax/g \
        -i glest.ini
  fi
fi
# servers.ini
[ -e servers.ini ] || cp $GLEST_DATA_DIR/servers.ini .
# launch the game
exec $GLEST_EXECUTABLE ${1+"$@"}
